# OptSlope

[![PyPI version](https://img.shields.io/pypi/v/optslope)](https://badge.fury.io/py/optslppe)
[![Python version](https://img.shields.io/pypi/pyversions/optslope)](https://www.python.org/downloads)
[![MIT license](https://img.shields.io/pypi/l/optslope)](https://mit-license.org/)

[![pipeline status](https://gitlab.com/elad.noor/optslope/badges/develop/pipeline.svg)](https://gitlab.com/elad.noor/optslppe/commits/develop)
[![codecov](https://codecov.io/gl/elad.noor/optslope/graph/badge.svg?token=jUwX9eOqRM)](https://codecov.io/gl/elad.noor/optslope)

A tool for metabolic engineering, based on the OptSlope algorithm.

## Relevant publications:
- Antonovsky, Niv, Shmuel Gleizer, Elad Noor, Yehudit Zohar, Elad Herz, Uri Barenholz, Lior Zelcbuch, et al. “Sugar Synthesis from CO2 in Escherichia Coli.” Cell 166, no. 1 (June 30, 2016): 115–25. https://doi.org/10.1016/j.cell.2016.05.064.
- Gleizer, Shmuel, Roee Ben-Nissan, Yinon M Bar-On, Niv Antonovsky, Elad Noor, Yehudit Zohar, Ghil Jona, et al. “Conversion of Escherichia Coli to Generate All Biomass Carbon from CO2.” Cell 179, no. 6 (November 27, 2019): 1255-1263.e12. https://doi.org/10.1016/j.cell.2019.11.009.
- Aslan, Selçuk, Elad Noor, Sara Benito Vaquerizo, Steffen N. Lindner, and Arren Bar-Even. “Design and Engineering of E. Coli Metabolic Sensor Strains with a Wide Sensitivity Range for Glycerate.” Metabolic Engineering 57 (January 1, 2020): 96–109. https://doi.org/10.1016/j.ymben.2019.09.002.
- Keller, Philipp, Elad Noor, Fabian Meyer, Michael A. Reiter, Stanislav Anastassov, Patrick Kiefer, and Julia A. Vorholt. “Methanol-Dependent Escherichia Coli Strains with a Complete Ribulose Monophosphate Cycle.” Nature Communications 11, no. 1 (October 26, 2020): 5403. https://doi.org/10.1038/s41467-020-19235-5.
- Satanowski, Ari, Beau Dronsella, Elad Noor, Bastian Vögeli, Hai He, Philipp Wichmann, Tobias J. Erb, Steffen N. Lindner, and Arren Bar-Even. “Awakening a Latent Carbon Fixation Cycle in Escherichia Coli.” Nature Communications 11, no. 1 (November 16, 2020): 5812. https://doi.org/10.1038/s41467-020-19564-5.
- Keller, Philipp, Michael A. Reiter, Patrick Kiefer, Thomas Gassler, Lucas Hemmerle, Philipp Christen, Elad Noor, and Julia A. Vorholt. “Generation of an Escherichia Coli Strain Growing on Methanol via the Ribulose Monophosphate Cycle.” Nature Communications 13, no. 1 (September 6, 2022): 5243. https://doi.org/10.1038/s41467-022-32744-9.
